@@ -11,7 +11,7 @@
  *
  * @since 3.1.0
  *
- * @param int|object|null $post Post ID or post object. Optional, default is the current post from the loop.
+ * @param int|WP_Post|null $post Optional. Post ID or post object. Defaults to the current post in the loop.
  * @return string|false The format if successful. False otherwise.
  */
 function get_post_format( $post = null ) {
@@ -41,9 +41,10 @@ function get_post_format( $post = null ) {
  *
  * @since 3.1.0
  *
- * @param string|array     $format Optional. The format or formats to check.
- * @param WP_Post|int|null $post   Optional. The post to check. If not supplied, defaults to the current post if used in the loop.
- * @return bool True if the post has any of the given formats (or any format, if no format specified), false otherwise.
+ * @param string|string[]  $format Optional. The format or formats to check. Default empty array.
+ * @param WP_Post|int|null $post   Optional. The post to check. Defaults to the current post in the loop.
+ * @return bool True if the post has any of the given formats (or any format, if no format specified),
+ *              false otherwise.
  */
 function has_post_format( $format = array(), $post = null ) {
 	$prefixed = array();
@@ -62,9 +63,9 @@ function has_post_format( $format = array(), $post = null ) {
  *
  * @since 3.1.0
  *
- * @param int|object $post   The post for which to assign a format.
- * @param string     $format A format to assign. Use an empty string or array to remove all formats from the post.
- * @return array|WP_Error|false WP_Error on error. Array of affected term IDs on success.
+ * @param int|WP_Post $post   The post for which to assign a format.
+ * @param string      $format A format to assign. Use an empty string or array to remove all formats from the post.
+ * @return array|WP_Error|false Array of affected term IDs on success. WP_Error on error.
  */
 function set_post_format( $post, $format ) {
 	$post = get_post( $post );
@@ -75,7 +76,7 @@ function set_post_format( $post, $format ) {
 
 	if ( ! empty( $format ) ) {
 		$format = sanitize_key( $format );
-		if ( 'standard' === $format || ! in_array( $format, get_post_format_slugs() ) ) {
+		if ( 'standard' === $format || ! in_array( $format, get_post_format_slugs(), true ) ) {
 			$format = '';
 		} else {
 			$format = 'post-format-' . $format;
@@ -185,14 +186,14 @@ function _post_format_request( $qvs ) {
  *
  * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
  *
- * @param string $link
- * @param object $term
- * @param string $taxonomy
+ * @param string  $link
+ * @param WP_Term $term
+ * @param string  $taxonomy
  * @return string
  */
 function _post_format_link( $link, $term, $taxonomy ) {
 	global $wp_rewrite;
-	if ( 'post_format' != $taxonomy ) {
+	if ( 'post_format' !== $taxonomy ) {
 		return $link;
 	}
 	if ( $wp_rewrite->get_extra_permastruct( $taxonomy ) ) {
@@ -231,14 +232,14 @@ function _post_format_get_term( $term ) {
  * @return array
  */
 function _post_format_get_terms( $terms, $taxonomies, $args ) {
-	if ( in_array( 'post_format', (array) $taxonomies ) ) {
-		if ( isset( $args['fields'] ) && 'names' == $args['fields'] ) {
+	if ( in_array( 'post_format', (array) $taxonomies, true ) ) {
+		if ( isset( $args['fields'] ) && 'names' === $args['fields'] ) {
 			foreach ( $terms as $order => $name ) {
 				$terms[ $order ] = get_post_format_string( str_replace( 'post-format-', '', $name ) );
 			}
 		} else {
 			foreach ( (array) $terms as $order => $term ) {
-				if ( isset( $term->taxonomy ) && 'post_format' == $term->taxonomy ) {
+				if ( isset( $term->taxonomy ) && 'post_format' === $term->taxonomy ) {
 					$terms[ $order ]->name = get_post_format_string( str_replace( 'post-format-', '', $term->slug ) );
 				}
 			}
@@ -258,7 +259,7 @@ function _post_format_get_terms( $terms, $taxonomies, $args ) {
  */
 function _post_format_wp_get_object_terms( $terms ) {
 	foreach ( (array) $terms as $order => $term ) {
-		if ( isset( $term->taxonomy ) && 'post_format' == $term->taxonomy ) {
+		if ( isset( $term->taxonomy ) && 'post_format' === $term->taxonomy ) {
 			$terms[ $order ]->name = get_post_format_string( str_replace( 'post-format-', '', $term->slug ) );
 		}
 	}
